==> eui-76.1.0.tgz: package/test-env/components/key_pad_menu/key_pad_menu.a11y.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _key_pad_menu = require("./key_pad_menu");

var _key_pad_menu_item = require("./key_pad_menu_item");

var _icon = require("../icon");

var _services = require("../../services");

var _react2 = require("@emotion/react");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */
/// <reference types="../../../cypress/support"/>
var KeyPadMenu = function KeyPadMenu() {
  var keypadButtonId__1 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'first'
  });
  var keypadButtonId__2 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'second'
  });
  var keypadButtonId__3 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'third'
  });
  var keypadButtonId__4 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'fourth'
  });
  var keypadButtonId__5 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'fifth'
  });
  var keypadButtonId__6 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'sixth'
  });

  var _useState = (0, _react.useState)(keypadButtonId__6),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      selectedID = _useState2[0],
      setSelectedID = _useState2[1];

  return (0, _react2.jsx)("div", {
    "aria-label": "Menu keypad"
  }, (0, _react2.jsx)(_key_pad_menu.EuiKeyPadMenu, null, (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-button-1",
    id: keypadButtonId__1,
    label: "Button 1",
    isSelected: selectedID === keypadButtonId__1,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__1);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "grid",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-button-2",
    id: keypadButtonId__2,
    label: "Button 2",
    isSelected: selectedID === keypadButtonId__2,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__2);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "grid",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-button-3",
    id: keypadButtonId__3,
    label: "Button 3",
    isSelected: selectedID === keypadButtonId__3,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__3);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "grid",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-link-1",
    id: keypadButtonId__4,
    label: "Link 1",
    href: "#/navigation/key-pad-menu",
    isSelected: selectedID === keypadButtonId__4,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__4);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "link",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-link-2",
    id: keypadButtonId__5,
    label: "Link 2",
    href: "#/navigation/key-pad-menu",
    isSelected: selectedID === keypadButtonId__5,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__5);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "link",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-link-3",
    id: keypadButtonId__6,
    label: "Disabled Link 3",
    isDisabled: true,
    isSelected: selectedID === keypadButtonId__6
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "link",
    size: "l"
  }))));
};

beforeEach(function () {
  cy.realMount((0, _react2.jsx)(KeyPadMenu, null));
  cy.get('div[aria-label="Menu keypad"]').should('exist');
});
describe('EuiKeyPadMenu', function () {
  describe('Automated accessibility check', function () {
    it('has zero violations on first render', function () {
      cy.checkAxe();
    });
    it('has zero violations on item click', function () {
      cy.get('a[data-test-subj="cy-keypad-link-2"]').realClick();
      cy.get('a[data-test-subj="cy-keypad-link-2"]').should('have.class', 'euiKeyPadMenuItem-isSelected');
      cy.checkAxe();
    });
    it('has zero violations on item keypress', function () {
      cy.repeatRealPress('Tab', 3);
      cy.get('button[data-test-subj="cy-keypad-button-3"]').should('have.focus');
      cy.realPress('Space');
      cy.get('button[data-test-subj="cy-keypad-button-3"]').should('have.class', 'euiKeyPadMenuItem-isSelected');
      cy.checkAxe();
      cy.realPress(['Shift', 'Tab']);
      cy.get('button[data-test-subj="cy-keypad-button-2"]').should('have.focus');
      cy.realPress('Space');
      cy.get('button[data-test-subj="cy-keypad-button-2"]').should('have.class', 'euiKeyPadMenuItem-isSelected');
      cy.get('button[data-test-subj="cy-keypad-button-3"]').should('not.have.class', 'euiKeyPadMenuItem-isSelected');
      cy.checkAxe();
    });
  });
});

==> eui-95.7.0.tgz: package/test-env/components/key_pad_menu/key_pad_menu.a11y.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _typeof = require("@babel/runtime/helpers/typeof");
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _key_pad_menu = require("./key_pad_menu");
var _key_pad_menu_item = require("./key_pad_menu_item");
var _icon = require("../icon");
var _services = require("../../services");
var _react2 = require("@emotion/react");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != _typeof(e) && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */

/// <reference types="cypress" />
/// <reference types="cypress-real-events" />
/// <reference types="../../../cypress/support" />

var KeyPadMenu = function KeyPadMenu() {
  var keypadButtonId__1 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'first'
  });
  var keypadButtonId__2 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'second'
  });
  var keypadButtonId__3 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'third'
  });
  var keypadButtonId__4 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'fourth'
  });
  var keypadButtonId__5 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'fifth'
  });
  var keypadButtonId__6 = (0, _services.useGeneratedHtmlId)({
    prefix: 'keypadButton',
    suffix: 'sixth'
  });
  var _useState = (0, _react.useState)(keypadButtonId__6),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    selectedID = _useState2[0],
    setSelectedID = _useState2[1];
  return (0, _react2.jsx)("div", {
    "aria-label": "Menu keypad"
  }, (0, _react2.jsx)(_key_pad_menu.EuiKeyPadMenu, null, (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-button-1",
    id: keypadButtonId__1,
    label: "Button 1",
    isSelected: selectedID === keypadButtonId__1,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__1);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "grid",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-button-2",
    id: keypadButtonId__2,
    label: "Button 2",
    isSelected: selectedID === keypadButtonId__2,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__2);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "grid",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-button-3",
    id: keypadButtonId__3,
    label: "Button 3",
    isSelected: selectedID === keypadButtonId__3,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__3);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "grid",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-link-1",
    id: keypadButtonId__4,
    label: "Link 1",
    href: "#/navigation/key-pad-menu",
    isSelected: selectedID === keypadButtonId__4,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__4);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "link",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-link-2",
    id: keypadButtonId__5,
    label: "Link 2",
    href: "#/navigation/key-pad-menu",
    isSelected: selectedID === keypadButtonId__5,
    onClick: function onClick() {
      return setSelectedID(keypadButtonId__5);
    }
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "link",
    size: "l"
  })), (0, _react2.jsx)(_key_pad_menu_item.EuiKeyPadMenuItem, {
    "data-test-subj": "cy-keypad-link-3",
    id: keypadButtonId__6,
    label: "Disabled Link 3",
    isDisabled: true,
    isSelected: selectedID === keypadButtonId__6
  }, (0, _react2.jsx)(_icon.EuiIcon, {
    type: "link",
    size: "l"
  }))));
};
beforeEach(function () {
  cy.realMount((0, _react2.jsx)(KeyPadMenu, null));
  cy.get('div[aria-label="Menu keypad"]').should('exist');
});
describe('EuiKeyPadMenu', function () {
  describe('Automated accessibility check', function () {
    it('has zero violations on first render', function () {
      cy.checkAxe();
    });
    it('has zero violations on item click', function () {
      cy.get('a[data-test-subj="cy-keypad-link-2"]').realClick();
      cy.get('a[data-test-subj="cy-keypad-link-2"]').should('have.attr', 'aria-current', 'true');
      cy.checkAxe();
    });
    it('has zero violations on item keypress', function () {
      cy.repeatRealPress('Tab', 3);
      cy.get('button[data-test-subj="cy-keypad-button-3"]').should('have.focus');
      cy.realPress('Space');
      cy.get('button[data-test-subj="cy-keypad-button-3"]').should('have.attr', 'aria-pressed', 'true');
      cy.checkAxe();
      cy.realPress(['Shift', 'Tab']);
      cy.get('button[data-test-subj="cy-keypad-button-2"]').should('have.attr', 'aria-pressed', 'false');
      cy.realPress('Space');
      cy.get('button[data-test-subj="cy-keypad-button-2"]').invoke('attr', 'aria-pressed').should('equal', 'true');
      cy.get('button[data-test-subj="cy-keypad-button-3"]').invoke('attr', 'aria-pressed').should('equal', 'false');
      cy.checkAxe();
    });
  });
});
